@@ -70,9 +70,10 @@ extern "C" {
  *
  * Macro providing the version of the library as
  * version * 1,000,000 + minor * 1000 + micro
+ *
+ * Since: 0.0.1
  */
-
-# define LIBVIR_VERSION_NUMBER 8002000
+# define LIBVIR_VERSION_NUMBER 8004000
 
 /**
  * LIBVIR_CHECK_VERSION:
@@ -86,6 +87,8 @@ extern "C" {
  *   #if LIBVIR_CHECK_VERSION(1,1,3)
  *     // some code that only works in 1.1.3 and newer
  *   #endif
+ *
+ * Since: 1.2.0
  */
 # define LIBVIR_CHECK_VERSION(major, minor, micro) \
     ((major) * 1000000 + (minor) * 1000 + (micro) <= LIBVIR_VERSION_NUMBER)
@@ -104,17 +107,24 @@ extern "C" {
  * from a context which is not re-entrant safe. Failure to
  * abide by this requirement may lead to application deadlocks
  * or crashes.
+ *
+ * Since: 0.5.0
  */
 typedef void (*virFreeCallback)(void *opaque);
 
+/**
+ * virConnectCloseReason:
+ *
+ * Since: 0.10.0
+ */
 typedef enum {
-    VIR_CONNECT_CLOSE_REASON_ERROR     = 0, /* Misc I/O error */
-    VIR_CONNECT_CLOSE_REASON_EOF       = 1, /* End-of-file from server */
-    VIR_CONNECT_CLOSE_REASON_KEEPALIVE = 2, /* Keepalive timer triggered */
-    VIR_CONNECT_CLOSE_REASON_CLIENT    = 3, /* Client requested it */
+    VIR_CONNECT_CLOSE_REASON_ERROR     = 0, /* Misc I/O error (Since: 0.10.0) */
+    VIR_CONNECT_CLOSE_REASON_EOF       = 1, /* End-of-file from server (Since: 0.10.0) */
+    VIR_CONNECT_CLOSE_REASON_KEEPALIVE = 2, /* Keepalive timer triggered (Since: 0.10.0) */
+    VIR_CONNECT_CLOSE_REASON_CLIENT    = 3, /* Client requested it (Since: 0.10.0) */
 
 # ifdef VIR_ENUM_SENTINELS
-    VIR_CONNECT_CLOSE_REASON_LAST
+    VIR_CONNECT_CLOSE_REASON_LAST /* (Since: 0.10.0) */
 # endif
 } virConnectCloseReason;
 
@@ -122,18 +132,20 @@ typedef enum {
  * virTypedParameterType:
  *
  * Express the type of a virTypedParameter
+ *
+ * Since: 0.9.2
  */
 typedef enum {
-    VIR_TYPED_PARAM_INT     = 1, /* integer case */
-    VIR_TYPED_PARAM_UINT    = 2, /* unsigned integer case */
-    VIR_TYPED_PARAM_LLONG   = 3, /* long long case */
-    VIR_TYPED_PARAM_ULLONG  = 4, /* unsigned long long case */
-    VIR_TYPED_PARAM_DOUBLE  = 5, /* double case */
-    VIR_TYPED_PARAM_BOOLEAN = 6, /* boolean(character) case */
-    VIR_TYPED_PARAM_STRING  = 7, /* string case */
+    VIR_TYPED_PARAM_INT     = 1, /* integer case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_UINT    = 2, /* unsigned integer case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_LLONG   = 3, /* long long case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_ULLONG  = 4, /* unsigned long long case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_DOUBLE  = 5, /* double case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_BOOLEAN = 6, /* boolean(character) case (Since: 0.9.2) */
+    VIR_TYPED_PARAM_STRING  = 7, /* string case (Since: 0.9.8) */
 
 # ifdef VIR_ENUM_SENTINELS
-    VIR_TYPED_PARAM_LAST
+    VIR_TYPED_PARAM_LAST /* (Since: 0.9.10) */
 # endif
 } virTypedParameterType;
 
@@ -143,6 +155,8 @@ typedef enum {
  * Flags related to libvirt APIs that use virTypedParameter.
  *
  * These enums should not conflict with those of virDomainModificationImpact.
+ *
+ * Since: 0.9.8
  */
 typedef enum {
     /* 1 << 0 is reserved for virDomainModificationImpact */
@@ -157,6 +171,8 @@ typedef enum {
      * the user does not have to worry about it; however, manually
      * setting the flag can be used to reject servers that cannot
      * return typed strings, even if no strings would be returned.
+     *
+     * Since: 0.9.8
      */
     VIR_TYPED_PARAM_STRING_OKAY = 1 << 2,
 
@@ -166,6 +182,8 @@ typedef enum {
  * VIR_TYPED_PARAM_FIELD_LENGTH:
  *
  * Macro providing the field length of virTypedParameter name
+ *
+ * Since: 0.9.2
  */
 # define VIR_TYPED_PARAM_FIELD_LENGTH 80
 
@@ -177,6 +195,8 @@ typedef enum {
  * The types virSchedParameter, virBlkioParameter, and
  * virMemoryParameter are aliases of this type, for use when
  * targeting libvirt earlier than 0.9.2.
+ *
+ * Since: 0.9.2
  */
 typedef struct _virTypedParameter virTypedParameter;
 
@@ -198,6 +218,8 @@ struct _virTypedParameter {
  * virTypedParameterPtr:
  *
  * a pointer to a virTypedParameter structure.
+ *
+ * Since: 0.9.2
  */
 typedef virTypedParameter *virTypedParameterPtr;
 
